==> fispro_3.4.orig.tar.gz: fispro-3.4/java/fis/MainFIS.java <==
//***********************************************************************
//
//                              MainFIS.java
//
// Author(s) : Jean-luc LABLEE
// FISPRO Version : 3.2 - Copyright INRA - Cemagref - 2002 - IDDN.FR.001.030024.000.R.P.2005.003.31235
// Licence http://www.cecill.info/licences/Licence_CeCILL_V2-en.html/
// Last modification date:  July 31, 2009 - Contact : fispro@supagro.inra.fr
//
//**********************************************************************
package fis;

import java.awt.Image;
import java.net.URL;
import java.util.StringTokenizer;
import java.util.Vector;

import javax.swing.Icon;
import javax.swing.ImageIcon;

//------------------------------------------------------------------------------
public class MainFIS
{
  static LocaleFIS locale;
  static ConfigFIS config;
  static LookFIS look;
  static jnifis jni;
  static JFISConsole Console = null;
  static ImageIcon fisproIcon = null;
  static Vector<Image> icons = new Vector<Image>();


//------------------------------------------------------------------------------
  public MainFIS()
  {
  try { jbInit(); }
  catch(Throwable t)
    {
    MessageFIS.Error(null,t);
    System.exit(-1);
    }
  }
//------------------------------------------------------------------------------
  public static void main(String[] args) { MainFIS mainSIF = new MainFIS(); }
//------------------------------------------------------------------------------
  private void jbInit() throws Throwable
  {
  look = new LookFIS();         // creation de l'objet de look
  config = new ConfigFIS();     // creation de l'objet de configuration de l'application
  locale = new LocaleFIS( config.Language(), config.Country() );  // creation de l'objet de localisation
  jni = new jnifis();                                             // creation de l'objet JNI
  jnifis.setUserHomeFisproPath(config.GetUserHomeFisproPath());
  // lecture des proprietees fis et data
  String fis = System.getProperty("fis", null);
  String data = System.getProperty("data", null);
  // creation des icones
  ClassLoader cl = this.getClass().getClassLoader();  // Get current classloader
  fisproIcon = new ImageIcon((new ImageIcon(cl.getResource("resources/fispro.gif"))).getImage().getScaledInstance(90, 90, Image.SCALE_SMOOTH)); 
  icons.add(new ImageIcon(getClass().getResource("/resources/fispro.icon.16.png")).getImage());
  icons.add(new ImageIcon(getClass().getResource("/resources/fispro.icon.32.png")).getImage());
  icons.add(new ImageIcon(getClass().getResource("/resources/fispro.icon.48.png")).getImage());
  // ouverture d'une Frame SIF par defaut
  JFISFrame f = new JFISFrame(fis == null ? null : new JFIS(fis, false), data == null ? null : JExtendedDataFile.Open(data, true), null);
  }
  
//------------------------------------------------------------------------------
/**
 * teste si JAVA3D est installe et le numero de version installe
 * @return true si JAVA3D est installe et compatible avec le numero de version
 */
public static boolean isJava3DIsInstalled() {
      String version = "1.3.1";
      try {
      Class cls = Class.forName("javax.media.j3d.SceneGraphObject");
      Package pkg = cls.getPackage();
      if(isVersionCompatibleWith(pkg.getImplementationVersion(), version) == false) {
          MessageFIS.Error(null, LocaleFIS.GetString("Error"), LocaleFIS.GetString("YouMustInstallJAVA3D") + " " + version );
          return false;
          }
      return true;
      } catch (ClassNotFoundException e1) {
          MessageFIS.Error(null, LocaleFIS.GetString("Error"), LocaleFIS.GetString("YouMustInstallJAVA3D") + " " + version );
          return false;
      }
  }
  
/**
 * Compare this specification version with a desired version 
 * @param specVersion version string of the specification version
 * @param desired version string of the desired version
 * @return true if the specification version number is greater than or equal to the desired version number
 * @throws NumberFormatException
 */
private static boolean isVersionCompatibleWith(String specVersion, String desired) throws NumberFormatException
  {
    if (specVersion == null || specVersion.length() < 1) {
        throw new NumberFormatException("Empty version string");
    }

    // Until it matches scan and compare numbers
    StringTokenizer dtok = new StringTokenizer(desired, ".", true);
    StringTokenizer stok = new StringTokenizer(specVersion, ".", true);
    while (dtok.hasMoreTokens() || stok.hasMoreTokens()) {
        int dver;
        int sver;
        if (dtok.hasMoreTokens()) {
        dver = Integer.parseInt(dtok.nextToken());
        } else
        dver = 0;

        if (stok.hasMoreTokens()) {
        sver = Integer.parseInt(stok.nextToken());
        } else
        sver = 0;

        if (sver < dver)
            return false;       // Known to be incompatible
        if (sver > dver)
            return true;        // Known to be compatible

        // Check for and absorb seperators
        if (dtok.hasMoreTokens())
            dtok.nextToken();
        if (stok.hasMoreTokens())
            stok.nextToken();
        // Compare next component
    }
    // All components numerically equal
    return true;
  }

}

==> fispro_3.5.orig.tar.gz: fispro-3.5/java/fis/MainFIS.java <==
//***********************************************************************
//
//                              MainFIS.java
//
// Author(s) : Jean-luc LABLEE
// FISPRO Version : 3.2 - Copyright INRA - Cemagref - 2002 - IDDN.FR.001.030024.000.R.P.2005.003.31235
// Licence http://www.cecill.info/licences/Licence_CeCILL_V2-en.html/
// Last modification date:  July 31, 2009 - Contact : fispro@supagro.inra.fr
//
//**********************************************************************
package fis;

import static util.swing.SwingUtilities.configureButtonFocus;

import java.awt.Image;
import java.net.URL;
import java.util.Locale;
import java.util.StringTokenizer;
import java.util.Vector;

import javax.swing.Icon;
import javax.swing.ImageIcon;

import org.apache.commons.io.FilenameUtils;

//------------------------------------------------------------------------------
public class MainFIS
{
  static LocaleFIS locale;
  static ConfigFIS config;
  static LookFIS look;
  static jnifis jni;
  static JFISConsole Console = null;
  static ImageIcon fisproIcon = null;
  static Vector<Image> icons = new Vector<Image>();


//------------------------------------------------------------------------------
  public MainFIS(String[] args)
  {
  try { jbInit(args); }
  catch(Throwable t)
    {
    MessageFIS.Error(null,t);
    System.exit(-1);
    }
  }
//------------------------------------------------------------------------------
  public static void main(String[] args) { 
	  MainFIS mainSIF = new MainFIS(args); 
  }
//------------------------------------------------------------------------------
  private void jbInit(String[] args) throws Throwable
  {
  configureButtonFocus();
  look = new LookFIS();         // creation de l'objet de look
  config = new ConfigFIS();     // creation de l'objet de configuration de l'application
  locale = new LocaleFIS( config.Language(), config.Country() );  // creation de l'objet de localisation
  jni = new jnifis();                                             // creation de l'objet JNI
  jnifis.setLocale();
  jnifis.setUserHomeFisproPath(config.GetUserHomeFisproPath());
  // lecture des proprietees fis et data
  String fis = getFIS(System.getProperty("fis", null), args);
  String data = System.getProperty("data", null);
  // creation des icones
  ClassLoader cl = this.getClass().getClassLoader();  // Get current classloader
  fisproIcon = new ImageIcon((new ImageIcon(cl.getResource("resources/fispro.gif"))).getImage().getScaledInstance(90, 90, Image.SCALE_SMOOTH)); 
  icons.add(new ImageIcon(getClass().getResource("/resources/fispro.icon.16.png")).getImage());
  icons.add(new ImageIcon(getClass().getResource("/resources/fispro.icon.32.png")).getImage());
  icons.add(new ImageIcon(getClass().getResource("/resources/fispro.icon.48.png")).getImage());
  // ouverture d'une Frame SIF par defaut
  JFISFrame f = new JFISFrame(fis == null ? null : new JFIS(fis, false), data == null ? null : JExtendedDataFile.Open(data, true), null);
  }
  
private String getFIS(String fis, String[] args) {
	return fis != null ? fis : getFIS(args);
}
private String getFIS(String[] args) {
	return args.length != 1 ? null : getFIS(args[0]);
}
private String getFIS(String arg) {
	return FilenameUtils.getExtension(arg).equals("fis") ? arg : null;
}
//------------------------------------------------------------------------------
/**
 * teste si JAVA3D est installe et le numero de version installe
 * @return true si JAVA3D est installe et compatible avec le numero de version
 */
public static boolean isJava3DIsInstalled() {
      String version = "1.3.1";
      try {
      Class cls = Class.forName("javax.media.j3d.SceneGraphObject");
      Package pkg = cls.getPackage();
      if(isVersionCompatibleWith(pkg.getImplementationVersion(), version) == false) {
          MessageFIS.Error(null, LocaleFIS.GetString("Error"), LocaleFIS.GetString("YouMustInstallJAVA3D") + " " + version );
          return false;
          }
      return true;
      } catch (ClassNotFoundException e1) {
          MessageFIS.Error(null, LocaleFIS.GetString("Error"), LocaleFIS.GetString("YouMustInstallJAVA3D") + " " + version );
          return false;
      }
  }
  
/**
 * Compare this specification version with a desired version 
 * @param specVersion version string of the specification version
 * @param desired version string of the desired version
 * @return true if the specification version number is greater than or equal to the desired version number
 * @throws NumberFormatException
 */
private static boolean isVersionCompatibleWith(String specVersion, String desired) throws NumberFormatException
  {
    if (specVersion == null || specVersion.length() < 1) {
        throw new NumberFormatException("Empty version string");
    }

    // Until it matches scan and compare numbers
    StringTokenizer dtok = new StringTokenizer(desired, ".", true);
    StringTokenizer stok = new StringTokenizer(specVersion, ".", true);
    while (dtok.hasMoreTokens() || stok.hasMoreTokens()) {
        int dver;
        int sver;
        if (dtok.hasMoreTokens()) {
        dver = Integer.parseInt(dtok.nextToken());
        } else
        dver = 0;

        if (stok.hasMoreTokens()) {
        sver = Integer.parseInt(stok.nextToken());
        } else
        sver = 0;

        if (sver < dver)
            return false;       // Known to be incompatible
        if (sver > dver)
            return true;        // Known to be compatible

        // Check for and absorb seperators
        if (dtok.hasMoreTokens())
            dtok.nextToken();
        if (stok.hasMoreTokens())
            stok.nextToken();
        // Compare next component
    }
    // All components numerically equal
    return true;
  }
}
